==> tine20-allinone_2020.03.4.tar.bz2: ActiveSync/js/ActiveSync-lang-da-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of ActiveSync **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/ActiveSync'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:48+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Danish (http://www.transifex.com/tine20/tine20/language/da/)\nLanguage: da\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Default Address book"
: ""

, "The default address book to create new contacts in."
: ""

, "Default Calendar"
: "Standard Kalender"

, "The default calendar to create new events in."
: "Standard kalender til at oprette nye begivenheder i."

, "Default Task List"
: "Standard Opgaveliste"

, "The default task list to create new tasks in."
: "Standard opgavelist til at oprette nye opgaver i."

, "Sync Devices"
: ""

, "Device ID"
: ""

, "Devicetype"
: ""

, "Owner"
: ""

, "Policy"
: ""

, "ActiveSync Version"
: ""

, "User agent"
: ""

, "Model"
: ""

, "IMEI"
: ""

, "Friendly Name"
: ""

, "OS"
: ""

, "OS Language"
: ""

, "Phonenumber"
: ""

, "Sync Device, Sync Devices"
: [
  ""
 ,""

]
, "Device, Devices"
: [
  "Enhed"
 ,"Enheder"

]
, "Devices"
: "Enheder"

, "Active Sync"
: "Active Sync"

, "Select a Device"
: "Vælg en enhed"

, "No ActiveSync Device registered"
: "Ingen ActiveSync enheder er registreret"

, "Set as {0} Filter"
: "Sæt som {0} filter"

, "Resetted Sync Filter"
: "nulstillede Sync Filter"

, "{0} filter for device \"{1}\" is now \"{2}\""
: "{0} filter for enheder \"{1}\" er nu \"{2}\""

, "resetted"
: "nulstillede"

, "Set Sync Filter"
: "Sæt Sync Filer"

, "ID"
: ""

, "Device Type"
: ""

, "Operating System"
: ""

, "Phone Number"
: ""

, "Ping Lifetime"
: ""

, "Ping Folder"
: ""

, "Remote Wipe"
: ""

, "Calendar Filter"
: ""

, "Contacts Filter"
: ""

, "E-mail Filter"
: ""

, "Tasks Filter"
: ""

, "Last Ping"
: ""

, "Monitor Last Ping"
: ""

, "Remote Device Reset"
: ""

, "Please Confirm"
: ""

, "Do you really want to wipe the selected devices? All personal data will be removed and the device will be reset to factory settings!"
: ""

, "Quicksearch"
: ""

, "Default Policy"
: "Standard Politik"

, "Default Policy installed during setup"
: "Standard politik under opsætning"

, "Default policy for new devices"
: "Standard politik for nye enheder"

, "Enter the id of the policy to apply to newly created devices."
: "Indtast ID'et for politikken du vil tildele nyligt oprettede enheder"

, "User Agent Deny List"
: ""

, "Array of regular expressions of User-Agent strings"
: ""

, "Disable Access Log"
: ""

, "Disable ActiveSync Access Log creation."
: ""

, "Filter timeslot for e-mails"
: ""

, "For how long in the past the e-mails should be synchronized."
: ""

, "Filter timeslot for events"
: ""

, "For how long in the past the events should be synchronized."
: ""

, "Manage ActiveSync devices"
: ""

, "See, edit and delete ActiveSync devices"
: ""

, "Reset ActiveSync devices"
: ""

, "Remotely reset ActiveSync devices to factory state, deleting all data"
: ""



, "Sync Device"
: ""

, "Device"
: "Enhed"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: ActiveSync/js/ActiveSync-lang-da-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of ActiveSync **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/ActiveSync'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:43+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Danish (http://www.transifex.com/tine20/tine20/language/da/)\nLanguage: da\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Active Sync"
: "Active Sync"

, "Select a Device"
: "Vælg en enhed"

, "No ActiveSync Device registered"
: "Ingen ActiveSync enheder er registreret"

, "Set as {0} Filter"
: "Sæt som {0} filter"

, "Resetted Sync Filter"
: "nulstillede Sync Filter"

, "{0} filter for device \"{1}\" is now \"{2}\""
: "{0} filter for enheder \"{1}\" er nu \"{2}\""

, "resetted"
: "nulstillede"

, "Set Sync Filter"
: "Sæt Sync Filer"

, "Sync Devices"
: ""

, "ID"
: ""

, "Device ID"
: ""

, "Device Type"
: ""

, "Owner"
: ""

, "Policy"
: ""

, "ActiveSync Version"
: ""

, "User agent"
: ""

, "Model"
: ""

, "IMEI"
: ""

, "Friendly Name"
: ""

, "Operating System"
: ""

, "OS Language"
: ""

, "Phone Number"
: ""

, "Ping Lifetime"
: ""

, "Ping Folder"
: ""

, "Remote Wipe"
: ""

, "Calendar Filter"
: ""

, "Contacts Filter"
: ""

, "E-mail Filter"
: ""

, "Tasks Filter"
: ""

, "Last Ping"
: ""

, "Monitor Last Ping"
: ""

, "Remote Device Reset"
: ""

, "Please Confirm"
: ""

, "Do you really want to wipe the selected devices? All personal data will be removed and the device will be reset to factory settings!"
: ""

, "Quicksearch"
: ""

, "Sync Device, Sync Devices"
: [
  ""
 ,""

]
, "Device, Devices"
: [
  "Enhed"
 ,"Enheder"

]
, "Devices"
: "Enheder"

, "Devicetype"
: ""

, "OS"
: ""

, "Phonenumber"
: ""

, "Default Address book"
: ""

, "The default address book to create new contacts in."
: ""

, "Default Calendar"
: "Standard Kalender"

, "The default calendar to create new events in."
: "Standard kalender til at oprette nye begivenheder i."

, "Default Task List"
: "Standard Opgaveliste"

, "The default task list to create new tasks in."
: "Standard opgavelist til at oprette nye opgaver i."

, "Default policy for new devices"
: "Standard politik for nye enheder"

, "Enter the id of the policy to apply to newly created devices."
: "Indtast ID'et for politikken du vil tildele nyligt oprettede enheder"

, "Device Model Agent Deny List"
: ""

, "Array of regular expressions of Device-Model strings"
: ""

, "User Agent Deny List"
: ""

, "Array of regular expressions of User-Agent strings"
: ""

, "Disable Access Log"
: ""

, "Disable ActiveSync Access Log creation."
: ""

, "Filter timeslot for e-mails"
: ""

, "For how long in the past the e-mails should be synchronized."
: ""

, "Filter timeslot for events"
: ""

, "For how long in the past the events should be synchronized."
: ""

, "%1$s ActiveSync failure"
: ""

, "Dear user,"
: ""

, "%1$s has noticed that the syncronization with your ActiveSync device is no longer active. Please trigger the syncronisation on your device."
: ""

, "Thank you."
: ""

, "Your %1$s Team"
: ""

, "Default Policy"
: "Standard Politik"

, "Default Policy installed during setup"
: "Standard politik under opsætning"

, "Manage ActiveSync devices"
: ""

, "See, edit and delete ActiveSync devices"
: ""

, "Reset ActiveSync devices"
: ""

, "Remotely reset ActiveSync devices to factory state, deleting all data"
: ""



, "Sync Device"
: ""

, "Device"
: "Enhed"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
